@@ -5,12 +5,21 @@ use lib qw( ../../lib ../../../lib ../../../../lib);
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::String_Mutation - Single character string mutation
+Algorithm::Evolutionary::Op::String_Mutation - Bit-flip mutation
 
 =head1 SYNOPSIS
 
-  #Create from scratch with priority = 2
-  my $op = new Algorithm::Evolutionary::Op::String_Mutation 2; 
+  my $xmlStr2=<<EOC; #howMany should be integer
+  <op name='String_Mutation' type='unary' rate='0.5' >
+    <param name='howMany' value='2' /> 
+  </op>
+  EOC
+  my $ref2 = XMLin($xmlStr2);
+
+  my $op2 = Algorithm::Evolutionary::Op::Base->fromXML( $ref2 );
+  print $op2->asXML(), "\n*Arity ", $op->arity(), "\n";
+
+  my $op = new Algorithm::Evolutionary::Op::String_Mutation 2; #Create from scratch with default rate
 
 =head1 Base Class
 
@@ -18,7 +27,8 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
-Mutation operator for a GA; changes a single character in the string.
+Mutation operator for a GA; changes a single bit in the string; 
+does not need a rate
 
 =head1 METHODS 
 
@@ -26,9 +36,10 @@ Mutation operator for a GA; changes a single character in the string.
 
 package Algorithm::Evolutionary::Op::String_Mutation;
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.7 $ =~ /(\d+)\.(\d+)/g; 
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; 
 
 use Carp;
+use Clone::Fast qw(clone);
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
@@ -37,7 +48,7 @@ our $ARITY = 1;
 
 =head2 new( [$how_many] [,$priority] )
 
-Creates a new mutation operator with an application rate that defaults to 0.5,
+Creates a new mutation operator with a bitflip application rate, which defaults to 0.5,
 and an operator application rate (general for all ops), which defaults to 1.
 
 =cut
@@ -49,7 +60,7 @@ sub new {
 
   my $hash = { howMany => $howMany || 1};
   my $self = Algorithm::Evolutionary::Op::Base::new( 'Algorithm::Evolutionary::Op::String_Mutation', 
-			 $rate, $hash );
+						     $rate, $hash );
   return $self;
 }
 
@@ -76,17 +87,18 @@ sub apply ($;$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
   my $victim = $arg->clone();
-  my $size =  length($victim->{'_str'});
+  my $size =  $victim->size();
 
   croak "Too many changes" if $self->{'_howMany'} >= $size;
-  my @char_array = 0..($size-1); # Avoids double mutation in a single place
+  my @char_array = 0..($size-1); # Hash with all bits
+  my @chars =@{ $victim->{'_chars'}};
   for ( my $i = 0; $i < $self->{'_howMany'}; $i++ ) {
       my $rnd = int (rand( @char_array ));
       my $who = splice(@char_array, $rnd, 1 );
       my $what = $victim->Atom( $who );
-      my @these_chars = @{ $victim->{'_chars'}};
-      for ( my $c = 0; $c < @{ $victim->{'_chars'}}; $c++ ) { #Exclude this character
-	if ( $victim->{'_chars'}[$c] eq $what ) {
+      my @these_chars = @chars;
+      for ( my $c = 0; $c <= $#chars; $c++ ) { #Exclude this character
+	if ( $chars[$c] eq $what ) {
 	  splice( @these_chars, $c, 1 );
 	  last;
 	}
@@ -102,10 +114,10 @@ sub apply ($;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2013/01/05 12:01:58 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/String_Mutation.pm,v 3.7 2013/01/05 12:01:58 jmerelo Exp $ 
+  CVS Info: $Date: 2009/11/25 10:11:33 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/String_Mutation.pm,v 3.2 2009/11/25 10:11:33 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.7 $
+  $Revision: 3.2 $
   $Name $
 
 =cut
