@@ -12,8 +12,11 @@ Algorithm::Evolutionary::Wheel - Random selector of things depending on probabil
 
 =head1 DESCRIPTION
 
-Creates a "roulette wheel" for spinning and selecting stuff. It will be
-used in several places; mainly in the L<Algorithm::Evolutionary::Op::CanonicalGA>. 
+Creates a "roulette wheel" for spinning and selecting stuff. It will
+be used in several places; mainly in the
+L<Algorithm::Evolutionary::Op::CanonicalGA>.  Take care that fitness
+must be non-zero positives; since if they aren't, roulette wheel won't
+work at all
 
 =head1 METHODS
 
@@ -22,7 +25,7 @@ used in several places; mainly in the L<Algorithm::Evolutionary::Op::CanonicalGA
 package Algorithm::Evolutionary::Wheel;
 use Carp;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.2 $ ' =~ / (\d+\.\d+)/ ) ;
 
 =head2 new( @probabilites )
 
@@ -36,24 +39,24 @@ sub new {
   my @probs = @_;
   
   my $self;
-  $self->{_accProbs} = ();
+  $self->{'_accProbs'} = [ 0 ];
   
   my $acc = 0;
   for ( @probs ) { $acc += $_;}
+  croak "The sum of fitness is 0, can't use roulette wheel\n" if ! $acc;
   for ( @probs ) { $_ /= $acc;} #Normalizes array
-
+  
   #Now creates the accumulated array
   my $aux = 0;  
   for ( @probs ) {
-	push @{$self->{_accProbs}}, $_ + $aux;
+	push @{$self->{'_accProbs'}}, $_ + $aux;
 	$aux += $_;
   }
-
   bless $self, $class;
   return $self;
 }
 
-=head2 spin()
+=head2 spin( [$number_of_individuals = 1])
 
 Returns an individual whose probability is related to its fitness
 
@@ -61,10 +64,25 @@ Returns an individual whose probability is related to its fitness
 
 sub spin {
   my $self = shift;
+  my $number_of_individuals = shift || 1;
   my $i = 0;
-  my $rand = rand();
-  while ( $self->{_accProbs}[$i] < $rand ) { $i++ };
-  return $i;
+  my @rand;
+  for my $n ( 1..$number_of_individuals ) {
+    push @rand, rand();
+  }
+  my @individuals;
+  for ( my $i = 0; $i < @{$self->{'_accProbs'}}-1; $i ++ ) {
+    for my  $r ( @rand ) {
+#      print $self->{'_accProbs'}[$i], " ", $r, " ", $self->{'_accProbs'}[$i+1], "\n";
+      push(@individuals, $i) if (( $self->{'_accProbs'}[$i] < $r ) &&
+				 ( $self->{_accProbs}[$i+1] > $r ) )
+    }
+  }
+  if ( $number_of_individuals > 1 ) {
+    return @individuals;
+  } else {
+    return $individuals[0];
+  }
   
 }
 =head1 Copyright
@@ -72,8 +90,8 @@ sub spin {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Wheel.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2010/01/17 17:49:50 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Wheel.pm,v 3.2 2010/01/17 17:49:50 jmerelo Exp $ 
   $Author: jmerelo $ 
 
 =cut
